
<template>
    <div class="dialog-table-container">
        <div>
            <el-input
                @change="search"
                size="small"
                v-model="stage"
                clearable
                suffix-icon="el-icon-search"
                placeholder="请输入清单期号"
                style="width: 180px; margin-bottom: 10px"
            ></el-input>
        </div>
        <div class="table-contaier" ref="tableContaier">
            <el-table
                :element-loading-background="loadingColor"
                v-loading="loading"
                align="center"
                :data="tableData"
                height="58vh"
                class="dialog_table"
                :cell-style="{'text-align': 'center'}"
                :header-cell-style="{'text-align': 'center'}"
            >
                <el-table-column type="expand" label="点击查看详情" width="140">
                    <template slot-scope="props">
                        <el-form
                            label-position="top"
                            class="dialog-table-expand"
                        >
                            <el-row>
                                <el-form-item label="推进状态：">
                                    <span>{{
                                        getDictName(
                                            'tjzt',
                                            props.row.propulsiveStatus
                                        )
                                    }}</span>
                                </el-form-item>
                            </el-row>
                            <el-row>
                                <el-form-item label="已开展的工作：">
                                    <span>{{
                                        props.row.propulsiveDetailed
                                    }}</span>
                                </el-form-item>
                            </el-row>
                            <el-row>
                                <el-form-item label="存在问题：">
                                    <span>{{
                                        props.row.existingProblems
                                    }}</span>
                                </el-form-item>
                            </el-row>
                        </el-form>
                    </template>
                </el-table-column>
                <el-table-column
                    prop="demandTopic"
                    label="需求题目"
                    width="180"
                >
                </el-table-column>
                <el-table-column
                    prop="demandSourceChannel"
                    label="来源渠道"
                    width="140"
                >
                    <template slot-scope="props">
                        {{
                            getDictName(
                                'ggbb_lyqd',
                                props.row.demandSourceChannel
                            )
                        }}
                    </template>
                </el-table-column>
                <el-table-column prop="demandField" label="所属领域">
                    <template slot-scope="props">
                        {{ getDictName('ggbb_ssly', props.row.demandField) }}
                    </template>
                </el-table-column>
                <el-table-column prop="demandNo" label="清单期号">
                    <template slot-scope="props">
                        {{ props.row.propulsiveYear }}年{{
                            props.row.demandNo
                        }}期
                    </template>
                </el-table-column>
            </el-table>
        </div>
        <pagenation
            :pageResult="params.pageBean"
            @currentChange="pageChange"
            class="pagenation"
        ></pagenation>
    </div>
</template>

  <script>
import apiList from '@/api/bigScreen/districView.js'
import pagenation from './pagenation.vue'
import utils from '@/utils.js'
export default {
    components: {pagenation},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            stage: '',
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.PROPULSIVE_YEAR_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LESS_EQUAL',
                        parentGroup: '',
                        property: 'a.PROPULSIVE_QUARTER_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.RESPONSIBLE_UNIT_CODE_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                ],
                sorter: [
                    {
                        direction: 'DESC',
                        property: 'create_time_',
                    },
                ],
            },
            ggbb_ssly: [],
            ggbb_cyzty: [],
            tableData: [],
        }
    },
    mounted() {
        this.querysParams = this.$route.query
        let {code} = this.querysParams
        let {quarter, year} = this.tableOptions
        this.loadData(code, quarter, year)
    },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        loadData(code, quarter, year) {
            this.loading = true
            this.params.querys[0].value = year
            this.params.querys[1].value = quarter
            this.params.querys[2].value = code
            apiList.reformDemandDetailList(this.params).then((res) => {
                if (res && res.rows) {
                    this.tableData = res.rows
                    this.params.pageBean.page = res.page
                    this.params.pageBean.pageSize = res.pageSize
                    this.params.pageBean.total = res.total
                }
                this.loading = false
            })
        },
        pageChange(key) {
            let {code} = this.querysParams
            let {quarter, year} = this.tableOptions
            this.params.pageBean.page = key
            this.loadData(code, quarter, year)
        },
        search(key) {
            this.stage = key
            this.params.querys[0].value = key
            this.params.pageBean.page = 1
            this.loadData()
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/ .dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}
/deep/ .el-input__inner {
    background-color: rgba(1, 47, 115, 0.6);
    border: 1px solid #0273E9;
    color: #fff;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
